==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/plugin/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Robert BOGENSCHNEIDER <robog@gmx.de>
 * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
 */
$lang['menu']                  = 'Administri Kromaĵojn';
$lang['download']              = 'Elŝuti kaj instali novan kromaĵon';
$lang['manage']                = 'Instalitaj kromaĵoj';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'ĝisdatigo';
$lang['btn_delete']            = 'forigi';
$lang['btn_settings']          = 'agordoj';
$lang['btn_download']          = 'Elŝuti';
$lang['btn_enable']            = 'Konservi';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalite:';
$lang['lastupdate']            = 'Laste ĝisdatigite:';
$lang['source']                = 'Fonto:';
$lang['unknown']               = 'nekonate';
$lang['updating']              = 'Ĝisdatiganta ...';
$lang['updated']               = 'Kromaĵo %s estas sukcese ĝisdatigita';
$lang['updates']               = 'La jenaj kromaĵoj estas sukcese ĝisdatigitaj';
$lang['update_none']           = 'Neniu ĝisdatigo troviĝas.';
$lang['deleting']              = 'Foriganta ...';
$lang['deleted']               = 'Kromaĵo %s estas forigita.';
$lang['downloading']           = 'Elŝutanta ...';
$lang['downloaded']            = 'La kromaĵo %s estas sukcese instalita';
$lang['downloads']             = 'La jenaj kromaĵoj estas sukcese instalitaj:';
$lang['download_none']         = 'Neniu kromaĵo troveblas, aŭ eble okazis nekonata problemo dum elŝuto kaj instalo.';
$lang['plugin']                = 'Kromaĵo:';
$lang['components']            = 'Komponeroj';
$lang['noinfo']                = 'Tiu ĉi kromaĵo liveris neniun informon: eble ĝi ne validas.';
$lang['name']                  = 'Nomo:';
$lang['date']                  = 'Dato:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Priskribo:';
$lang['author']                = 'Aŭtoro:';
$lang['www']                   = 'Retpaĝo:';
$lang['error']                 = 'Nekonata eraro okazis.';
$lang['error_download']        = 'Maleblas elŝuti la kromaĵan dosieron: %s';
$lang['error_badurl']          = 'Suspektinda malbona URL - maleblas difini la dosieran nomon el la URL';
$lang['error_dircreate']       = 'Maleblas krei provizoran dosierujon por ricevi elŝutaĵon';
$lang['error_decompress']      = 'La administrilo de kromaĵoj ne kapablis malkompakti la elŝutitan dosieron. Tio povas esti pro malkompleta elŝuto, tiaokaze vi devus provi refoje; aŭ eble la kompakta formato ne estas konata, tiaokaze vi bezonos elŝuti kaj instali la kromaĵon permane.';
$lang['error_copy']            = 'Okazis eraro de dosierkopio dum provo instali dosierojn por la kromaĵo &lt;em&gt;%s&lt;/em&gt;: la disko povus esti plenplena aŭ aliro-rajtoj povus esti misdifinitaj. Tio povus rezulti en malkomplete instalita kromaĵo kaj igi vian vikion malstabila.';
$lang['error_delete']          = 'Okazis eraro dum provo forigi la kromaĵon &lt;em&gt;%s&lt;/em&gt;. Plejprobable tio sekvas de nesufiĉa rajto por aliri la dosieron aŭ ties ujon.';
$lang['enabled']               = 'La kromaĵo %s estas ebligita.';
$lang['notenabled']            = 'La kromaĵo %s ne povis esti ebligita, kontrolu dosier-permesojn.';
$lang['disabled']              = 'La kromaĵo %s estas malebligita.';
$lang['notdisabled']           = 'La kromaĵo %s ne povis esti malebligita, kontrolu dosier-permesojn.';
$lang['packageinstalled']      = 'Kromaĵa pakaĵo (%d kromaĵo(j): %s) sukcese instalitaj.';

==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/plugin/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert BOGENSCHNEIDER <robog@gmx.de>
 * @author Robert Bogenschneider <bogi@uea.org>
 * @author Robert Bogenschneider <robog@gmx.de>
 */
$lang['menu']                  = 'Administri Kromaĵojn';
$lang['download']              = 'Elŝuti kaj instali novan kromaĵon';
$lang['manage']                = 'Instalitaj kromaĵoj';
$lang['btn_info']              = 'Info';
$lang['btn_update']            = 'Ĝisdatigo';
$lang['btn_delete']            = 'Forigi';
$lang['btn_settings']          = 'agordoj';
$lang['btn_download']          = 'Elŝuti';
$lang['btn_enable']            = 'Konservi';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalite:';
$lang['lastupdate']            = 'Laste ĝisdatigite:';
$lang['source']                = 'Fonto:';
$lang['unknown']               = 'nekonate';
$lang['updating']              = 'Ĝisdatiganta ...';
$lang['updated']               = 'Kromaĵo %s estas sukcese ĝisdatigita';
$lang['updates']               = 'Jenaj kromaĵoj estas sukcese ĝisdatigitaj';
$lang['update_none']           = 'Neniu ĝisdatigo troviĝas.';
$lang['deleting']              = 'Foriganta ...';
$lang['deleted']               = 'Kromaĵo %s estas forigita.';
$lang['downloading']           = 'Elŝutanta ...';
$lang['downloaded']            = 'La kromaĵo %s estas sukcese instalita';
$lang['downloads']             = 'Jenaj kromaĵoj estas sukcese instalitaj:';
$lang['download_none']         = 'Neniu kromaĵo troveblas, aŭ eble okazis nekonata problemo dum elŝuto kaj instalo.';
$lang['plugin']                = 'Kromaĵo:';
$lang['components']            = 'Komponantoj';
$lang['noinfo']                = 'Tiu ĉi kromaĵo liveris neniun informon: eble ĝi ne validas.';
$lang['name']                  = 'Nomo:';
$lang['date']                  = 'Dato:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Priskribo:';
$lang['author']                = 'Aŭtoro:';
$lang['www']                   = 'Retpaĝo:';
$lang['error']                 = 'Nekonata eraro okazis.';
$lang['error_download']        = 'Maleblas elŝuti la kromaĵan dosieron: %s';
$lang['error_badurl']          = 'Suspektinda malbona URL - maleblas difini la dosieran nomon el la URL';
$lang['error_dircreate']       = 'Maleblas krei provizoran dosierujon por ricevi elŝutaĵon';
$lang['error_decompress']      = 'La administrilo de kromaĵoj ne kapablis malkompakti la elŝutitan dosieron. Tio povas esti pro malkompleta elŝuto, tiaokaze provu refoje; aŭ eble la kompakta formato ne estas konata, tiaokaze elŝutu kaj instalu la kromaĵon permane.';
$lang['error_copy']            = 'Okazis eraro de dosierkopio dum provo instali dosierojn por la kromaĵo <em>%s&</em>: la disko povus esti plenplena aŭ aliro-rajtoj povus esti misdifinitaj. Tio povus rezulti en malkomplete instalita kromaĵo kaj igi vian vikion malstabila.';
$lang['error_delete']          = 'Okazis eraro dum provo forigi la kromaĵon <em>%s</em>. Verŝajne tio sekvas de nesufiĉa rajto por aliri la dosieron aŭ ties ujon.';
$lang['enabled']               = 'La kromaĵo %s estas ebligita.';
$lang['notenabled']            = 'La kromaĵo %s ne povis esti ebligita, kontrolu dosier-permesojn.';
$lang['disabled']              = 'La kromaĵo %s estas malebligita.';
$lang['notdisabled']           = 'La kromaĵo %s ne povis esti malebligita, kontrolu dosier-permesojn.';
$lang['packageinstalled']      = 'Kromaĵa pakaĵo (%d kromaĵo(j): %s) sukcese instalita.';
